==> ejc-bfyjerp-impl-3.0.0-20241122.074806-59-sources.jar: com/ejianc/business/tax/controller/InvoiceOpenRegistController.java <==
package com.ejianc.business.tax.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.contract.bean.ContractManageEntity;
import com.ejianc.business.tax.bean.InvoiceOpenApplyEntity;
import com.ejianc.business.tax.service.IInvoiceOpenApplyService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.tax.bean.InvoiceOpenRegistEntity;
import com.ejianc.business.tax.service.IInvoiceOpenRegistService;
import com.ejianc.business.tax.vo.InvoiceOpenRegistVO;

/**
 * 税务管理-开票登记
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("invoiceOpenRegist")
public class InvoiceOpenRegistController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "TAX_OPEN_REGIST";//此处需要根据实际修改

    @Autowired
    private IInvoiceOpenRegistService service;
    @Autowired
    private IInvoiceOpenApplyService applyService;


    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<InvoiceOpenRegistVO> saveOrUpdate(@RequestBody InvoiceOpenRegistVO saveOrUpdateVO) {
    	InvoiceOpenRegistEntity entity = BeanMapper.map(saveOrUpdateVO, InvoiceOpenRegistEntity.class);
        Long oldApplyId=null;
    	if (null!=saveOrUpdateVO.getId()){
            InvoiceOpenRegistEntity invoiceOpenRegistEntity = service.selectById(saveOrUpdateVO.getId());
            oldApplyId=invoiceOpenRegistEntity.getApplyId();
        }
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        if(entity.getFlag()==null){
            entity.setFlag(0);
        }
    	service.saveOrUpdate(entity, false);
        if (null!=oldApplyId && !oldApplyId.equals(saveOrUpdateVO.getApplyId())){
            applyService.updOpenType(oldApplyId,0);
        }
    	if (null!=saveOrUpdateVO.getApplyId()){
            applyService.updOpenType(saveOrUpdateVO.getApplyId(),1);
        }
        InvoiceOpenRegistVO vo = BeanMapper.map(entity, InvoiceOpenRegistVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InvoiceOpenRegistVO> queryDetail(Long id) {
    	InvoiceOpenRegistEntity entity = service.selectById(id);
    	InvoiceOpenRegistVO vo = BeanMapper.map(entity, InvoiceOpenRegistVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<InvoiceOpenRegistVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (InvoiceOpenRegistVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
                if (null!=vo.getApplyId()){
                    applyService.updOpenType(vo.getApplyId(),0);
                }
            }
        }
        service.removeByIds(vos.stream().map(InvoiceOpenRegistVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<InvoiceOpenRegistVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("projectName","code"));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));


        IPage<InvoiceOpenRegistEntity> page = service.queryPage(param,false);
        IPage<InvoiceOpenRegistVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceOpenRegistVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("projectName","code"));
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<InvoiceOpenRegistEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().exportWithTrans("InvoiceOpenRegist-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refInvoiceOpenRegistData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<InvoiceOpenRegistVO>> refInvoiceOpenRegistData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        param.getParams().put("billState",new Parameter(QueryParam.IN,Arrays.asList(1,3)));
        param.getParams().put("flag",new Parameter(QueryParam.EQ,0));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            if(_con.containsKey("projectId")) {
                param.getParams().put("projectId", new Parameter(QueryParam.EQ, _con.getLong("projectId")));

            }
        }

        IPage<InvoiceOpenRegistEntity> page = service.queryPage(param,false);
        IPage<InvoiceOpenRegistVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceOpenRegistVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }



    /**
     * @Description 根据项目id查询单据的数据
     * @param
     * @Return void
     */
    @RequestMapping(value = "/queryInvoiceOpenProjectBillId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<JSONObject> queryInvoiceOpenProjectBillId(@RequestParam Long projectBillId) {
        JSONObject returnObject = new JSONObject();
        List<InvoiceOpenRegistEntity> detailList = service.list(new QueryWrapper<InvoiceOpenRegistEntity>().eq("project_bill_id", projectBillId));
        returnObject.put("detailList", detailList);
        return CommonResponse.success("查询列表数据成功！", returnObject);
    }
}

==> ejc-bfyjerp-impl-3.0.0-20250225.013449-149-sources.jar: com/ejianc/business/tax/controller/InvoiceOpenRegistController.java <==
package com.ejianc.business.tax.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.contract.bean.ContractManageEntity;
import com.ejianc.business.finance.bean.DaypayEntity;
import com.ejianc.business.tax.bean.InvoiceOpenApplyEntity;
import com.ejianc.business.tax.bean.OuterCertEntity;
import com.ejianc.business.tax.service.IInvoiceOpenApplyService;
import com.ejianc.business.tax.service.IOuterCertService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.tax.bean.InvoiceOpenRegistEntity;
import com.ejianc.business.tax.service.IInvoiceOpenRegistService;
import com.ejianc.business.tax.vo.InvoiceOpenRegistVO;

/**
 * 税务管理-开票登记
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("invoiceOpenRegist")
public class InvoiceOpenRegistController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "TAX_OPEN_REGIST";//此处需要根据实际修改
    @Autowired
    private IOuterCertService outerCertService;
    @Autowired
    private IInvoiceOpenRegistService service;
    @Autowired
    private IInvoiceOpenApplyService applyService;
    @Autowired
    private IInvoiceOpenApplyService invoiceOpenApplyService;


    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<InvoiceOpenRegistVO> saveOrUpdate(@RequestBody InvoiceOpenRegistVO saveOrUpdateVO) {
    	InvoiceOpenRegistEntity entity = BeanMapper.map(saveOrUpdateVO, InvoiceOpenRegistEntity.class);
        Long oldApplyId=null;
    	if (null!=saveOrUpdateVO.getId()){
            InvoiceOpenRegistEntity invoiceOpenRegistEntity = service.selectById(saveOrUpdateVO.getId());
            oldApplyId=invoiceOpenRegistEntity.getApplyId();
        }
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        if(entity.getFlag()==null){
            entity.setFlag(0);
        }
    	service.saveOrUpdate(entity, false);
        if (null!=oldApplyId && !oldApplyId.equals(saveOrUpdateVO.getApplyId())){
            applyService.updOpenType(oldApplyId,0);
        }
    	if (null!=saveOrUpdateVO.getApplyId()){
            applyService.updOpenType(saveOrUpdateVO.getApplyId(),1);
        }
        InvoiceOpenRegistVO vo = BeanMapper.map(entity, InvoiceOpenRegistVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InvoiceOpenRegistVO> queryDetail(Long id) {
    	InvoiceOpenRegistEntity entity = service.selectById(id);
    	InvoiceOpenRegistVO vo = BeanMapper.map(entity, InvoiceOpenRegistVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    /**
     * @Description 根据项目id查询金额
     * @param id
     */
    @RequestMapping(value = "/queryMnyByProjectId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InvoiceOpenRegistVO> queryMnyByProjectId(Long projectId) {
        LambdaQueryWrapper<InvoiceOpenRegistEntity> lambdaAccountWrapper = new LambdaQueryWrapper<>();
        lambdaAccountWrapper.in(InvoiceOpenRegistEntity::getBillState,1,3);
        lambdaAccountWrapper.eq(InvoiceOpenRegistEntity::getProjectId,projectId);
        List<InvoiceOpenRegistEntity> daypayEntityList = service.list(lambdaAccountWrapper);
        InvoiceOpenRegistVO invoiceOpenRegistVO = new InvoiceOpenRegistVO();
        //累计开票金额
        if (CollectionUtils.isNotEmpty(daypayEntityList)){
            BigDecimal sumOpenMny = daypayEntityList.stream().filter(s->s.getOpenMny() != null).map(InvoiceOpenRegistEntity::getOpenMny)
                    .reduce(BigDecimal.ZERO, BigDecimal::add);
            invoiceOpenRegistVO.setSumInvoiceTaxMny(sumOpenMny);
        }

        //累计外管证金额
        LambdaQueryWrapper<OuterCertEntity> lambdaOutCertWrapper = new LambdaQueryWrapper<>();
        lambdaOutCertWrapper.in(OuterCertEntity::getBillState,1,3);
        lambdaOutCertWrapper.eq(OuterCertEntity::getProjectId,projectId);
        List<OuterCertEntity> outerCertEntityList = outerCertService.list(lambdaOutCertWrapper);

        if (CollectionUtils.isNotEmpty(outerCertEntityList)){
            BigDecimal sumMny = outerCertEntityList.stream().filter(s->s.getMny() != null).map(OuterCertEntity::getMny)
                    .reduce(BigDecimal.ZERO, BigDecimal::add);
            invoiceOpenRegistVO.setSumCardTaxMny(sumMny);
        }

        return CommonResponse.success("查询详情数据成功！",invoiceOpenRegistVO);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<InvoiceOpenRegistVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (InvoiceOpenRegistVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
                if (null!=vo.getApplyId()){
                    applyService.updOpenType(vo.getApplyId(),0);
                }
            }
        }
        service.removeByIds(vos.stream().map(InvoiceOpenRegistVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<InvoiceOpenRegistVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("projectName","code"));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));


        IPage<InvoiceOpenRegistEntity> page = service.queryPage(param,false);
        IPage<InvoiceOpenRegistVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceOpenRegistVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("projectName","code"));
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<InvoiceOpenRegistEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().exportWithTrans("InvoiceOpenRegist-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refInvoiceOpenRegistData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<InvoiceOpenRegistVO>> refInvoiceOpenRegistData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        param.getParams().put("billState",new Parameter(QueryParam.IN,Arrays.asList(1,3)));
        param.getParams().put("flag",new Parameter(QueryParam.EQ,0));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            if(_con.containsKey("projectId")) {
                param.getParams().put("projectId", new Parameter(QueryParam.EQ, _con.getLong("projectId")));

            }
        }

        IPage<InvoiceOpenRegistEntity> page = service.queryPage(param,false);
        IPage<InvoiceOpenRegistVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), InvoiceOpenRegistVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }



    /**
     * @Description 根据项目id查询单据的数据
     * @param
     * @Return void
     */
    @RequestMapping(value = "/queryInvoiceOpenProjectBillId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<JSONObject> queryInvoiceOpenProjectBillId(@RequestParam Long projectBillId) {
        JSONObject returnObject = new JSONObject();
        List<InvoiceOpenRegistEntity> detailList = service.list(new QueryWrapper<InvoiceOpenRegistEntity>().eq("project_bill_id", projectBillId));
        returnObject.put("detailList", detailList);
        return CommonResponse.success("查询列表数据成功！", returnObject);
    }
}
